==> certmanager-model-v1alpha2-6.4.1-sources.jar: io/fabric8/certmanager/api/model/v1alpha2/CertificateListFluent.java <==
package io.fabric8.certmanager.api.model.v1alpha2;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface CertificateListFluent<A extends CertificateListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(Integer index,Certificate item);
  public A setToItems(Integer index,Certificate item);
  public A addToItems(io.fabric8.certmanager.api.model.v1alpha2.Certificate... items);
  public A addAllToItems(Collection<Certificate> items);
  public A removeFromItems(io.fabric8.certmanager.api.model.v1alpha2.Certificate... items);
  public A removeAllFromItems(Collection<Certificate> items);
  public A removeMatchingFromItems(Predicate<CertificateBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<Certificate> getItems();
  public List<Certificate> buildItems();
  public Certificate buildItem(Integer index);
  public Certificate buildFirstItem();
  public Certificate buildLastItem();
  public Certificate buildMatchingItem(Predicate<CertificateBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<CertificateBuilder> predicate);
  public A withItems(List<Certificate> items);
  public A withItems(io.fabric8.certmanager.api.model.v1alpha2.Certificate... items);
  public Boolean hasItems();
  public CertificateListFluent.ItemsNested<A> addNewItem();
  public CertificateListFluent.ItemsNested<A> addNewItemLike(Certificate item);
  public CertificateListFluent.ItemsNested<A> setNewItemLike(Integer index,Certificate item);
  public CertificateListFluent.ItemsNested<A> editItem(Integer index);
  public CertificateListFluent.ItemsNested<A> editFirstItem();
  public CertificateListFluent.ItemsNested<A> editLastItem();
  public CertificateListFluent.ItemsNested<A> editMatchingItem(Predicate<CertificateBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public interface ItemsNested<N> extends Nested<N>,CertificateFluent<CertificateListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}

==> certmanager-model-v1alpha2-6.7.2-sources.jar: io/fabric8/certmanager/api/model/v1alpha2/CertificateListFluent.java <==
package io.fabric8.certmanager.api.model.v1alpha2;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface CertificateListFluent<A extends CertificateListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(int index,Certificate item);
  public A setToItems(int index,Certificate item);
  public A addToItems(io.fabric8.certmanager.api.model.v1alpha2.Certificate... items);
  public A addAllToItems(Collection<Certificate> items);
  public A removeFromItems(io.fabric8.certmanager.api.model.v1alpha2.Certificate... items);
  public A removeAllFromItems(Collection<Certificate> items);
  public A removeMatchingFromItems(Predicate<CertificateBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<Certificate> getItems();
  public List<Certificate> buildItems();
  public Certificate buildItem(int index);
  public Certificate buildFirstItem();
  public Certificate buildLastItem();
  public Certificate buildMatchingItem(Predicate<CertificateBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<CertificateBuilder> predicate);
  public A withItems(List<Certificate> items);
  public A withItems(io.fabric8.certmanager.api.model.v1alpha2.Certificate... items);
  public Boolean hasItems();
  public CertificateListFluent.ItemsNested<A> addNewItem();
  public CertificateListFluent.ItemsNested<A> addNewItemLike(Certificate item);
  public CertificateListFluent.ItemsNested<A> setNewItemLike(int index,Certificate item);
  public CertificateListFluent.ItemsNested<A> editItem(int index);
  public CertificateListFluent.ItemsNested<A> editFirstItem();
  public CertificateListFluent.ItemsNested<A> editLastItem();
  public CertificateListFluent.ItemsNested<A> editMatchingItem(Predicate<CertificateBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public interface ItemsNested<N> extends Nested<N>,CertificateFluent<CertificateListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}
